@@ -7,7 +7,7 @@
 #  define AVOGADROCALC_NO_EXPORT
 #else
 #  ifndef AVOGADROCALC_EXPORT
-#    ifdef AvogadroCalc_EXPORTS
+#    ifdef Calc_EXPORTS
         /* We are building this library */
 #      define AVOGADROCALC_EXPORT __attribute__((visibility("default")))
 #    else
@@ -33,6 +33,7 @@
 #  define AVOGADROCALC_DEPRECATED_NO_EXPORT AVOGADROCALC_NO_EXPORT AVOGADROCALC_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef AVOGADROCALC_NO_DEPRECATED
 #    define AVOGADROCALC_NO_DEPRECATED
